classdef (InferiorClasses = {?mp}) intervalMatrix 
% intervalMatrix class 
%
% Syntax:  
%    obj = intervalMatrix(C,D)
%    obj = intervalMatrix(C,D,setting)
%
% Inputs:
%    C - center matrix
%    D - width matrix
%    setting - setting for multiplication ('sharpivmult' or 'standard')
%
% Outputs:
%    obj - generated object
%
% Example:
%   C = [0 2; 3 1];
%   D = [1 2; 1 1];
%
%   mi = intervalMatrix(C,D);
%
% Other m-files required: none
% Subfunctions: none
% MAT-files required: none
%
% See also: interval,  polytope

% Author:       Matthias Althoff
% Written:      18-June-2010
% Last update:  26-August-2011
%               15-June-2016
%               06-May-2021
% Last revision:---

%------------- BEGIN CODE --------------

properties (SetAccess = private, GetAccess = public)
    dim = 1;
    int = [];
    setting = 'sharpivmult';
end
    
methods 
    %class constructor
    function obj = intervalMatrix(matrixCenter,matrixDelta,setting)

        %one input
        if nargin==1
            if isa(matrixCenter,'intervalMatrix')
                obj = matrixCenter;
            else
                obj.dim = length(matrixCenter);
                obj.int = interval(matrixCenter,matrixCenter);
                obj.setting = [];
            end
        elseif nargin==2
            obj.dim = length(matrixCenter);
            %ensure positive matrix deltas
            matrixDelta=abs(matrixDelta);
            obj.int=interval(matrixCenter-matrixDelta,matrixCenter+matrixDelta);
            obj.setting = [];
        elseif nargin==3
            obj.dim = length(matrixCenter);
            %ensure positive matrix deltas
            matrixDelta=abs(matrixDelta);
            obj.int=interval(matrixCenter-matrixDelta,matrixCenter+matrixDelta);
            obj.setting = setting;  %settings: 'sharpivmult','fastivmult'
        end
    end
         
    %methods in seperate files 
    intMat = plus(summand1,summand2)
    intMat = mtimes(factor1,factor2)
    intMat = mpower(intMat,exponent)
    intMat = powers(varargin)
    [eI, iPow, E] = expm(varargin)
    [eI, iPow, E] = expmInd(varargin)
    [eI,eI2,iPow,iPow2,E] = expmMixed(matI,r,intermediateOrder,maxOrder)
    [eI,eI2,iPow,iPow2,E] = expmIndMixed(matI,intermediateOrder,maxOrder)
    M = abs(intMat)
    n = infNorm(intMat)
    E = exponentialRemainder(intMat,maxOrder)
    IH = interval(intMat)
    V = vertices(intMat)
    matP = matPolytope(intMat)
    matZ = matZonotope(intMat)
    A = randomSampling(intMat,varargin)
    dist = expmDist(intMat,exactMat,maxOrder)
    vol = volume(matI)
    val = expmNorm(intMat,t)
    val = expmNormInf(intMat,t)
    absBound = expmAbsoluteBound(intMat,t)
    normBoundErr = expmNormErr(intMat,r)  
    normBoundErr = expmNormErrInf(intMat,r)
    element = subsref(intMat, S)
    sq = exactSquare(A)
    res = norm(obj, varargin)
    
    %display functions
    plot(varargin)
    display(obj)
end
end

%------------- END OF CODE -------